# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class S3DestinationFormProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "csv_delimiter": "str",
        "output_file_format": "str",
        "s3_bucket": "str",
    }

    attribute_map = {
        "csv_delimiter": "csv_delimiter",
        "output_file_format": "output_file_format",
        "s3_bucket": "s3_bucket",
    }

    def __init__(
        self,
        csv_delimiter=None,
        output_file_format=None,
        s3_bucket=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """S3DestinationFormProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._csv_delimiter = None
        self._output_file_format = None
        self._s3_bucket = None
        self.discriminator = None

        if csv_delimiter is not None:
            self.csv_delimiter = csv_delimiter
        if output_file_format is not None:
            self.output_file_format = output_file_format
        if s3_bucket is not None:
            self.s3_bucket = s3_bucket

    @property
    def csv_delimiter(self):
        """Gets the csv_delimiter of this S3DestinationFormProperties.  # noqa: E501

        csv delimiter character  # noqa: E501

        :return: The csv_delimiter of this S3DestinationFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._csv_delimiter

    @csv_delimiter.setter
    def csv_delimiter(self, csv_delimiter):
        """Sets the csv_delimiter of this S3DestinationFormProperties.

        csv delimiter character  # noqa: E501

        :param csv_delimiter: The csv_delimiter of this S3DestinationFormProperties.  # noqa: E501
        :type: str
        """

        self._csv_delimiter = csv_delimiter

    @property
    def output_file_format(self):
        """Gets the output_file_format of this S3DestinationFormProperties.  # noqa: E501

        Defines the type of file Stitch will write to the bucket. Possible values are: - csv, which will use CSV (.csv) files - jsonl, which will use JSON (.jsonl) files   # noqa: E501

        :return: The output_file_format of this S3DestinationFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._output_file_format

    @output_file_format.setter
    def output_file_format(self, output_file_format):
        """Sets the output_file_format of this S3DestinationFormProperties.

        Defines the type of file Stitch will write to the bucket. Possible values are: - csv, which will use CSV (.csv) files - jsonl, which will use JSON (.jsonl) files   # noqa: E501

        :param output_file_format: The output_file_format of this S3DestinationFormProperties.  # noqa: E501
        :type: str
        """

        self._output_file_format = output_file_format

    @property
    def s3_bucket(self):
        """Gets the s3_bucket of this S3DestinationFormProperties.  # noqa: E501

        The name of the Amazon S3 bucket Stitch will write to.  # noqa: E501

        :return: The s3_bucket of this S3DestinationFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._s3_bucket

    @s3_bucket.setter
    def s3_bucket(self, s3_bucket):
        """Sets the s3_bucket of this S3DestinationFormProperties.

        The name of the Amazon S3 bucket Stitch will write to.  # noqa: E501

        :param s3_bucket: The s3_bucket of this S3DestinationFormProperties.  # noqa: E501
        :type: str
        """

        self._s3_bucket = s3_bucket

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3DestinationFormProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, S3DestinationFormProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class HookNotification(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "id": "int",
        "client_id": "int",
        "created_at": "datetime",
        "modified_at": "datetime",
        "disabled_at": "datetime",
        "type": "str",
        "version": "int",
        "config": "HookNotificationConfig",
    }

    attribute_map = {
        "id": "id",
        "client_id": "client_id",
        "created_at": "created_at",
        "modified_at": "modified_at",
        "disabled_at": "disabled_at",
        "type": "type",
        "version": "version",
        "config": "config",
    }

    def __init__(
        self,
        id=None,
        client_id=None,
        created_at=None,
        modified_at=None,
        disabled_at=None,
        type=None,
        version=None,
        config=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """HookNotification - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._client_id = None
        self._created_at = None
        self._modified_at = None
        self._disabled_at = None
        self._type = None
        self._version = None
        self._config = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if client_id is not None:
            self.client_id = client_id
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if disabled_at is not None:
            self.disabled_at = disabled_at
        if type is not None:
            self.type = type
        if version is not None:
            self.version = version
        if config is not None:
            self.config = config

    @property
    def id(self):
        """Gets the id of this HookNotification.  # noqa: E501

        The notification ID.  # noqa: E501

        :return: The id of this HookNotification.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HookNotification.

        The notification ID.  # noqa: E501

        :param id: The id of this HookNotification.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def client_id(self):
        """Gets the client_id of this HookNotification.  # noqa: E501

        The ID of the Stitch client account.  # noqa: E501

        :return: The client_id of this HookNotification.  # noqa: E501
        :rtype: int
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this HookNotification.

        The ID of the Stitch client account.  # noqa: E501

        :param client_id: The client_id of this HookNotification.  # noqa: E501
        :type: int
        """

        self._client_id = client_id

    @property
    def created_at(self):
        """Gets the created_at of this HookNotification.  # noqa: E501

        The time at which the notification was created.  # noqa: E501

        :return: The created_at of this HookNotification.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this HookNotification.

        The time at which the notification was created.  # noqa: E501

        :param created_at: The created_at of this HookNotification.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this HookNotification.  # noqa: E501

        The time at which the notification was last modified.  # noqa: E501

        :return: The modified_at of this HookNotification.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this HookNotification.

        The time at which the notification was last modified.  # noqa: E501

        :param modified_at: The modified_at of this HookNotification.  # noqa: E501
        :type: datetime
        """

        self._modified_at = modified_at

    @property
    def disabled_at(self):
        """Gets the disabled_at of this HookNotification.  # noqa: E501

        The time at which the notification was disabled. This will be null unless the notification has been disabled.   # noqa: E501

        :return: The disabled_at of this HookNotification.  # noqa: E501
        :rtype: datetime
        """
        return self._disabled_at

    @disabled_at.setter
    def disabled_at(self, disabled_at):
        """Sets the disabled_at of this HookNotification.

        The time at which the notification was disabled. This will be null unless the notification has been disabled.   # noqa: E501

        :param disabled_at: The disabled_at of this HookNotification.  # noqa: E501
        :type: datetime
        """

        self._disabled_at = disabled_at

    @property
    def type(self):
        """Gets the type of this HookNotification.  # noqa: E501

        The type of the notification. Possible values are: post_load   # noqa: E501

        :return: The type of this HookNotification.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this HookNotification.

        The type of the notification. Possible values are: post_load   # noqa: E501

        :param type: The type of this HookNotification.  # noqa: E501
        :type: str
        """
        allowed_values = ["post_load"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and type not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    @property
    def version(self):
        """Gets the version of this HookNotification.  # noqa: E501

        The version of the hook service the notification is using.  # noqa: E501

        :return: The version of this HookNotification.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this HookNotification.

        The version of the hook service the notification is using.  # noqa: E501

        :param version: The version of this HookNotification.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def config(self):
        """Gets the config of this HookNotification.  # noqa: E501


        :return: The config of this HookNotification.  # noqa: E501
        :rtype: HookNotificationConfig
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this HookNotification.


        :param config: The config of this HookNotification.  # noqa: E501
        :type: HookNotificationConfig
        """

        self._config = config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HookNotification):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HookNotification):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class SourceFormProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "anchor_time": "str",
        "api_type": "str",
        "client_id": "str",
        "client_secret": "str",
        "cron_expression": "str",
        "frequency_in_minutes": "str",
        "instance_url": "str",
        "is_sandbox": "str",
        "quota_percent_per_run": "str",
        "quota_percent_total": "str",
        "refresh_token": "str",
        "select_fields_by_default": "str",
        "start_date": "str",
        "quota_user": "str",
        "report_definitions": "list[GoogleAnalyticsSourceFormPropertiesReportDefinitions]",
        "api_secret": "str",
        "attribution_window": "str",
        "date_window_size": "str",
        "project_timezone": "str",
        "select_properties_by_default": "str",
    }

    attribute_map = {
        "anchor_time": "anchor_time",
        "api_type": "api_type",
        "client_id": "client_id",
        "client_secret": "client_secret",
        "cron_expression": "cron_expression",
        "frequency_in_minutes": "frequency_in_minutes",
        "instance_url": "instance_url",
        "is_sandbox": "is_sandbox",
        "quota_percent_per_run": "quota_percent_per_run",
        "quota_percent_total": "quota_percent_total",
        "refresh_token": "refresh_token",
        "select_fields_by_default": "select_fields_by_default",
        "start_date": "start_date",
        "quota_user": "quota_user",
        "report_definitions": "report_definitions",
        "api_secret": "api_secret",
        "attribution_window": "attribution_window",
        "date_window_size": "date_window_size",
        "project_timezone": "project_timezone",
        "select_properties_by_default": "select_properties_by_default",
    }

    def __init__(
        self,
        anchor_time=None,
        api_type=None,
        client_id=None,
        client_secret=None,
        cron_expression=None,
        frequency_in_minutes=None,
        instance_url=None,
        is_sandbox=None,
        quota_percent_per_run=None,
        quota_percent_total=None,
        refresh_token=None,
        select_fields_by_default=None,
        start_date=None,
        quota_user=None,
        report_definitions=None,
        api_secret=None,
        attribution_window=None,
        date_window_size=None,
        project_timezone=None,
        select_properties_by_default=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SourceFormProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._anchor_time = None
        self._api_type = None
        self._client_id = None
        self._client_secret = None
        self._cron_expression = None
        self._frequency_in_minutes = None
        self._instance_url = None
        self._is_sandbox = None
        self._quota_percent_per_run = None
        self._quota_percent_total = None
        self._refresh_token = None
        self._select_fields_by_default = None
        self._start_date = None
        self._quota_user = None
        self._report_definitions = None
        self._api_secret = None
        self._attribution_window = None
        self._date_window_size = None
        self._project_timezone = None
        self._select_properties_by_default = None
        self.discriminator = None

        if anchor_time is not None:
            self.anchor_time = anchor_time
        if api_type is not None:
            self.api_type = api_type
        if client_id is not None:
            self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if cron_expression is not None:
            self.cron_expression = cron_expression
        if frequency_in_minutes is not None:
            self.frequency_in_minutes = frequency_in_minutes
        if instance_url is not None:
            self.instance_url = instance_url
        if is_sandbox is not None:
            self.is_sandbox = is_sandbox
        if quota_percent_per_run is not None:
            self.quota_percent_per_run = quota_percent_per_run
        if quota_percent_total is not None:
            self.quota_percent_total = quota_percent_total
        if refresh_token is not None:
            self.refresh_token = refresh_token
        if select_fields_by_default is not None:
            self.select_fields_by_default = select_fields_by_default
        if start_date is not None:
            self.start_date = start_date
        if quota_user is not None:
            self.quota_user = quota_user
        if report_definitions is not None:
            self.report_definitions = report_definitions
        if api_secret is not None:
            self.api_secret = api_secret
        if attribution_window is not None:
            self.attribution_window = attribution_window
        if date_window_size is not None:
            self.date_window_size = date_window_size
        if project_timezone is not None:
            self.project_timezone = project_timezone
        if select_properties_by_default is not None:
            self.select_properties_by_default = select_properties_by_default

    @property
    def anchor_time(self):
        """Gets the anchor_time of this SourceFormProperties.  # noqa: E501

        Defines the time that frequency_in_minutes is \"anchored\" to, which Stitch will use to create the integration's replication schedule. In Stitch, this is referred to as Anchor Scheduling. This field must contain an ISO 8601-compliant date. Note: When Stitch stores this value, it will be in UTC. You should provide this value in UTC to ensure the desired anchor time is retained. For example: You want to create a schedule that is anchored to 1:00PM EST and runs every 6 hours (360 minutes). To do this, you can set anchor_time to something like 2018-04-30T17:00:00Z and frequency_in_minutes to 360. This means jobs would run at 23:00:00, 05:00:00, 11:00:00, and so on.   # noqa: E501

        :return: The anchor_time of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._anchor_time

    @anchor_time.setter
    def anchor_time(self, anchor_time):
        """Sets the anchor_time of this SourceFormProperties.

        Defines the time that frequency_in_minutes is \"anchored\" to, which Stitch will use to create the integration's replication schedule. In Stitch, this is referred to as Anchor Scheduling. This field must contain an ISO 8601-compliant date. Note: When Stitch stores this value, it will be in UTC. You should provide this value in UTC to ensure the desired anchor time is retained. For example: You want to create a schedule that is anchored to 1:00PM EST and runs every 6 hours (360 minutes). To do this, you can set anchor_time to something like 2018-04-30T17:00:00Z and frequency_in_minutes to 360. This means jobs would run at 23:00:00, 05:00:00, 11:00:00, and so on.   # noqa: E501

        :param anchor_time: The anchor_time of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._anchor_time = anchor_time

    @property
    def api_type(self):
        """Gets the api_type of this SourceFormProperties.  # noqa: E501

        The Salesforce API Stitch should use to extract data. Possible values are REST or BULK.   # noqa: E501

        :return: The api_type of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._api_type

    @api_type.setter
    def api_type(self, api_type):
        """Sets the api_type of this SourceFormProperties.

        The Salesforce API Stitch should use to extract data. Possible values are REST or BULK.   # noqa: E501

        :param api_type: The api_type of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._api_type = api_type

    @property
    def client_id(self):
        """Gets the client_id of this SourceFormProperties.  # noqa: E501

        The secure OAuth 2.0 identifier for the client application.   # noqa: E501

        :return: The client_id of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this SourceFormProperties.

        The secure OAuth 2.0 identifier for the client application.   # noqa: E501

        :param client_id: The client_id of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this SourceFormProperties.  # noqa: E501

        The secure OAuth 2.0 secret key for the client application.   # noqa: E501

        :return: The client_secret of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this SourceFormProperties.

        The secure OAuth 2.0 secret key for the client application.   # noqa: E501

        :param client_secret: The client_secret of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def cron_expression(self):
        """Gets the cron_expression of this SourceFormProperties.  # noqa: E501

        Note: Advanced Scheduling using Cron is not yet supported for this source. A value may be submitted for this property if the account is on an Enterprise plan, but Stitch will not use the expression submitted. A valid Quartz cron expression representing the replication schedule for the integration. Refer to the Advanced Scheduling documentation for more info. Note: If neither a cron_expression or frequency_in_minutes property is provided, Stitch will use the source's default frequency_in_minutes value (60).   # noqa: E501

        :return: The cron_expression of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._cron_expression

    @cron_expression.setter
    def cron_expression(self, cron_expression):
        """Sets the cron_expression of this SourceFormProperties.

        Note: Advanced Scheduling using Cron is not yet supported for this source. A value may be submitted for this property if the account is on an Enterprise plan, but Stitch will not use the expression submitted. A valid Quartz cron expression representing the replication schedule for the integration. Refer to the Advanced Scheduling documentation for more info. Note: If neither a cron_expression or frequency_in_minutes property is provided, Stitch will use the source's default frequency_in_minutes value (60).   # noqa: E501

        :param cron_expression: The cron_expression of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._cron_expression = cron_expression

    @property
    def frequency_in_minutes(self):
        """Gets the frequency_in_minutes of this SourceFormProperties.  # noqa: E501

        Defines how often, in minutes, Stitch should attempt to replicate data from Google Analytics. Accepted values are: - 30 - 60 - 360 - 720 - 1440   # noqa: E501

        :return: The frequency_in_minutes of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._frequency_in_minutes

    @frequency_in_minutes.setter
    def frequency_in_minutes(self, frequency_in_minutes):
        """Sets the frequency_in_minutes of this SourceFormProperties.

        Defines how often, in minutes, Stitch should attempt to replicate data from Google Analytics. Accepted values are: - 30 - 60 - 360 - 720 - 1440   # noqa: E501

        :param frequency_in_minutes: The frequency_in_minutes of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._frequency_in_minutes = frequency_in_minutes

    @property
    def instance_url(self):
        """Gets the instance_url of this SourceFormProperties.  # noqa: E501

        The url of the instance to connect to.  # noqa: E501

        :return: The instance_url of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._instance_url

    @instance_url.setter
    def instance_url(self, instance_url):
        """Sets the instance_url of this SourceFormProperties.

        The url of the instance to connect to.  # noqa: E501

        :param instance_url: The instance_url of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._instance_url = instance_url

    @property
    def is_sandbox(self):
        """Gets the is_sandbox of this SourceFormProperties.  # noqa: E501

        If `true`, the Salesforce account being connected is a sandbox.  # noqa: E501

        :return: The is_sandbox of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._is_sandbox

    @is_sandbox.setter
    def is_sandbox(self, is_sandbox):
        """Sets the is_sandbox of this SourceFormProperties.

        If `true`, the Salesforce account being connected is a sandbox.  # noqa: E501

        :param is_sandbox: The is_sandbox of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._is_sandbox = is_sandbox

    @property
    def quota_percent_per_run(self):
        """Gets the quota_percent_per_run of this SourceFormProperties.  # noqa: E501

        The maximum percentage of Salesforce API quota allowed per replication job.   # noqa: E501

        :return: The quota_percent_per_run of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._quota_percent_per_run

    @quota_percent_per_run.setter
    def quota_percent_per_run(self, quota_percent_per_run):
        """Sets the quota_percent_per_run of this SourceFormProperties.

        The maximum percentage of Salesforce API quota allowed per replication job.   # noqa: E501

        :param quota_percent_per_run: The quota_percent_per_run of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._quota_percent_per_run = quota_percent_per_run

    @property
    def quota_percent_total(self):
        """Gets the quota_percent_total of this SourceFormProperties.  # noqa: E501

        The maximum percentage of Salesforce API quota allowed per day.   # noqa: E501

        :return: The quota_percent_total of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._quota_percent_total

    @quota_percent_total.setter
    def quota_percent_total(self, quota_percent_total):
        """Sets the quota_percent_total of this SourceFormProperties.

        The maximum percentage of Salesforce API quota allowed per day.   # noqa: E501

        :param quota_percent_total: The quota_percent_total of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._quota_percent_total = quota_percent_total

    @property
    def refresh_token(self):
        """Gets the refresh_token of this SourceFormProperties.  # noqa: E501

        The OAuth 2.0 refresh token used to access the Google API.  # noqa: E501

        :return: The refresh_token of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this SourceFormProperties.

        The OAuth 2.0 refresh token used to access the Google API.  # noqa: E501

        :param refresh_token: The refresh_token of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._refresh_token = refresh_token

    @property
    def select_fields_by_default(self):
        """Gets the select_fields_by_default of this SourceFormProperties.  # noqa: E501

        If `true`, Stitch will automatically set new fields added in Salesforce to replicate.   # noqa: E501

        :return: The select_fields_by_default of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._select_fields_by_default

    @select_fields_by_default.setter
    def select_fields_by_default(self, select_fields_by_default):
        """Sets the select_fields_by_default of this SourceFormProperties.

        If `true`, Stitch will automatically set new fields added in Salesforce to replicate.   # noqa: E501

        :param select_fields_by_default: The select_fields_by_default of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._select_fields_by_default = select_fields_by_default

    @property
    def start_date(self):
        """Gets the start_date of this SourceFormProperties.  # noqa: E501

        The date from which Stitch should begin replicating data from Salesforce. Data from this date forward will be replicated. This field must contain an ISO 8601-compliant date, and the timestamp must be midnight. For example: 2018-01-01T00:00:00Z   # noqa: E501

        :return: The start_date of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this SourceFormProperties.

        The date from which Stitch should begin replicating data from Salesforce. Data from this date forward will be replicated. This field must contain an ISO 8601-compliant date, and the timestamp must be midnight. For example: 2018-01-01T00:00:00Z   # noqa: E501

        :param start_date: The start_date of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def quota_user(self):
        """Gets the quota_user of this SourceFormProperties.  # noqa: E501

        Note: This is a read-only property and will be returned when the Google Analytics object is successfully created. Including it in POST or PUT requests will result in InvalidProperties errors.   # noqa: E501

        :return: The quota_user of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._quota_user

    @quota_user.setter
    def quota_user(self, quota_user):
        """Sets the quota_user of this SourceFormProperties.

        Note: This is a read-only property and will be returned when the Google Analytics object is successfully created. Including it in POST or PUT requests will result in InvalidProperties errors.   # noqa: E501

        :param quota_user: The quota_user of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._quota_user = quota_user

    @property
    def report_definitions(self):
        """Gets the report_definitions of this SourceFormProperties.  # noqa: E501

        An array of objects, each object pertaining to a custom report you want to create. Note: Metrics and dimensions for each report can be selected when the source proceeds to the field_selection step.   # noqa: E501

        :return: The report_definitions of this SourceFormProperties.  # noqa: E501
        :rtype: list[GoogleAnalyticsSourceFormPropertiesReportDefinitions]
        """
        return self._report_definitions

    @report_definitions.setter
    def report_definitions(self, report_definitions):
        """Sets the report_definitions of this SourceFormProperties.

        An array of objects, each object pertaining to a custom report you want to create. Note: Metrics and dimensions for each report can be selected when the source proceeds to the field_selection step.   # noqa: E501

        :param report_definitions: The report_definitions of this SourceFormProperties.  # noqa: E501
        :type: list[GoogleAnalyticsSourceFormPropertiesReportDefinitions]
        """

        self._report_definitions = report_definitions

    @property
    def api_secret(self):
        """Gets the api_secret of this SourceFormProperties.  # noqa: E501

        The API secret of your project in your Mixpanel account. Refer to the Mixpanel documentation for instructions on obtaining this information.   # noqa: E501

        :return: The api_secret of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._api_secret

    @api_secret.setter
    def api_secret(self, api_secret):
        """Sets the api_secret of this SourceFormProperties.

        The API secret of your project in your Mixpanel account. Refer to the Mixpanel documentation for instructions on obtaining this information.   # noqa: E501

        :param api_secret: The api_secret of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._api_secret = api_secret

    @property
    def attribution_window(self):
        """Gets the attribution_window of this SourceFormProperties.  # noqa: E501

        Defines the number, in days, Stitch should use as an attribution window. To ensure your Mixpanel and Stitch settings align, we recommend using the same attribution window in Stitch that you use in Mixpanel. Mixpanel's default attribution window is five days (5). Refer to the Mixpanel documentation for more information about attribution windows for this integration.   # noqa: E501

        :return: The attribution_window of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._attribution_window

    @attribution_window.setter
    def attribution_window(self, attribution_window):
        """Sets the attribution_window of this SourceFormProperties.

        Defines the number, in days, Stitch should use as an attribution window. To ensure your Mixpanel and Stitch settings align, we recommend using the same attribution window in Stitch that you use in Mixpanel. Mixpanel's default attribution window is five days (5). Refer to the Mixpanel documentation for more information about attribution windows for this integration.   # noqa: E501

        :param attribution_window: The attribution_window of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._attribution_window = attribution_window

    @property
    def date_window_size(self):
        """Gets the date_window_size of this SourceFormProperties.  # noqa: E501

        Defines the number, in days, for a date looping window for the export, funnel, and revenue tables. Date looping will return records whose from_date and to_date fall between the number of days in the defined window size. Note: If your project has large volumes of events, you may want to set the number of days to 14, 7, or even to 1 or 2 days.   # noqa: E501

        :return: The date_window_size of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._date_window_size

    @date_window_size.setter
    def date_window_size(self, date_window_size):
        """Sets the date_window_size of this SourceFormProperties.

        Defines the number, in days, for a date looping window for the export, funnel, and revenue tables. Date looping will return records whose from_date and to_date fall between the number of days in the defined window size. Note: If your project has large volumes of events, you may want to set the number of days to 14, 7, or even to 1 or 2 days.   # noqa: E501

        :param date_window_size: The date_window_size of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._date_window_size = date_window_size

    @property
    def project_timezone(self):
        """Gets the project_timezone of this SourceFormProperties.  # noqa: E501

        The timezone in which your date-time fields are stored for your project. You can find your project timezone in the project settings in the Mixpanel console   # noqa: E501

        :return: The project_timezone of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._project_timezone

    @project_timezone.setter
    def project_timezone(self, project_timezone):
        """Sets the project_timezone of this SourceFormProperties.

        The timezone in which your date-time fields are stored for your project. You can find your project timezone in the project settings in the Mixpanel console   # noqa: E501

        :param project_timezone: The project_timezone of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._project_timezone = project_timezone

    @property
    def select_properties_by_default(self):
        """Gets the select_properties_by_default of this SourceFormProperties.  # noqa: E501

        A configuration parameter - the only accepted values are true and false. When set to true, this parameter captures new properties in the events and engage tables' records. If set to false, new properties will be ignored.   # noqa: E501

        :return: The select_properties_by_default of this SourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._select_properties_by_default

    @select_properties_by_default.setter
    def select_properties_by_default(self, select_properties_by_default):
        """Sets the select_properties_by_default of this SourceFormProperties.

        A configuration parameter - the only accepted values are true and false. When set to true, this parameter captures new properties in the events and engage tables' records. If set to false, new properties will be ignored.   # noqa: E501

        :param select_properties_by_default: The select_properties_by_default of this SourceFormProperties.  # noqa: E501
        :type: str
        """

        self._select_properties_by_default = select_properties_by_default

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceFormProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SourceFormProperties):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# import apis into api package
from stitch_connect_client.api.destinations_api import DestinationsApi
from stitch_connect_client.api.sources_api import SourcesApi
from stitch_connect_client.api.streams_api import StreamsApi

# flake8: noqa



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class StreamUpdate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "stream_id": "int",
        "selected": "bool",
        "stream_name": "str",
        "tap_stream_id": "str",
        "metadata": "list[StreamLevelMetadata]",
    }

    attribute_map = {
        "stream_id": "stream_id",
        "selected": "selected",
        "stream_name": "stream_name",
        "tap_stream_id": "tap_stream_id",
        "metadata": "metadata",
    }

    def __init__(
        self,
        stream_id=None,
        selected=None,
        stream_name=None,
        tap_stream_id=None,
        metadata=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """StreamUpdate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._stream_id = None
        self._selected = None
        self._stream_name = None
        self._tap_stream_id = None
        self._metadata = None
        self.discriminator = None

        if stream_id is not None:
            self.stream_id = stream_id
        if selected is not None:
            self.selected = selected
        if stream_name is not None:
            self.stream_name = stream_name
        if tap_stream_id is not None:
            self.tap_stream_id = tap_stream_id
        if metadata is not None:
            self.metadata = metadata

    @property
    def stream_id(self):
        """Gets the stream_id of this StreamUpdate.  # noqa: E501

        The stream ID.  # noqa: E501

        :return: The stream_id of this StreamUpdate.  # noqa: E501
        :rtype: int
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        """Sets the stream_id of this StreamUpdate.

        The stream ID.  # noqa: E501

        :param stream_id: The stream_id of this StreamUpdate.  # noqa: E501
        :type: int
        """

        self._stream_id = stream_id

    @property
    def selected(self):
        """Gets the selected of this StreamUpdate.  # noqa: E501

        Indicates if the stream is selected for replication. Possible values are: null - Only present if a stream has never been selected. Otherwise, this value will be true if selected, and false if de-selected. true - The stream is selected and data will be replicated for all selected fields false - The stream is not selected and data for this stream will not be replicated   # noqa: E501

        :return: The selected of this StreamUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._selected

    @selected.setter
    def selected(self, selected):
        """Sets the selected of this StreamUpdate.

        Indicates if the stream is selected for replication. Possible values are: null - Only present if a stream has never been selected. Otherwise, this value will be true if selected, and false if de-selected. true - The stream is selected and data will be replicated for all selected fields false - The stream is not selected and data for this stream will not be replicated   # noqa: E501

        :param selected: The selected of this StreamUpdate.  # noqa: E501
        :type: bool
        """

        self._selected = selected

    @property
    def stream_name(self):
        """Gets the stream_name of this StreamUpdate.  # noqa: E501

        The name of the stream. This value may not be unique. For example: A database with multiple schemas can have the same stream name in multiple schemas.   # noqa: E501

        :return: The stream_name of this StreamUpdate.  # noqa: E501
        :rtype: str
        """
        return self._stream_name

    @stream_name.setter
    def stream_name(self, stream_name):
        """Sets the stream_name of this StreamUpdate.

        The name of the stream. This value may not be unique. For example: A database with multiple schemas can have the same stream name in multiple schemas.   # noqa: E501

        :param stream_name: The stream_name of this StreamUpdate.  # noqa: E501
        :type: str
        """

        self._stream_name = stream_name

    @property
    def tap_stream_id(self):
        """Gets the tap_stream_id of this StreamUpdate.  # noqa: E501

        The unique version of the stream name. For database sources, this value will be the database name, schema name, and table name, combined.   # noqa: E501

        :return: The tap_stream_id of this StreamUpdate.  # noqa: E501
        :rtype: str
        """
        return self._tap_stream_id

    @tap_stream_id.setter
    def tap_stream_id(self, tap_stream_id):
        """Sets the tap_stream_id of this StreamUpdate.

        The unique version of the stream name. For database sources, this value will be the database name, schema name, and table name, combined.   # noqa: E501

        :param tap_stream_id: The tap_stream_id of this StreamUpdate.  # noqa: E501
        :type: str
        """

        self._tap_stream_id = tap_stream_id

    @property
    def metadata(self):
        """Gets the metadata of this StreamUpdate.  # noqa: E501


        :return: The metadata of this StreamUpdate.  # noqa: E501
        :rtype: list[StreamLevelMetadata]
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this StreamUpdate.


        :param metadata: The metadata of this StreamUpdate.  # noqa: E501
        :type: list[StreamLevelMetadata]
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StreamUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class FieldLevelMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "inclusion": "str",
        "selected": "bool",
        "selected_by_default": "bool",
        "sql_datatype": "str",
        "field_exclusions": "object",
        "unsupported_description": "str",
        "tap_google_analytics_cubes": "list[str]",
        "tap_google_analytics_group": "str",
        "behavior": "str",
    }

    attribute_map = {
        "inclusion": "inclusion",
        "selected": "selected",
        "selected_by_default": "selected-by-default",
        "sql_datatype": "sql-datatype",
        "field_exclusions": "fieldExclusions",
        "unsupported_description": "unsupported-description",
        "tap_google_analytics_cubes": "tap_google_analytics.cubes",
        "tap_google_analytics_group": "tap_google_analytics.group",
        "behavior": "behavior",
    }

    def __init__(
        self,
        inclusion=None,
        selected=None,
        selected_by_default=None,
        sql_datatype=None,
        field_exclusions=None,
        unsupported_description=None,
        tap_google_analytics_cubes=None,
        tap_google_analytics_group=None,
        behavior=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """FieldLevelMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._inclusion = None
        self._selected = None
        self._selected_by_default = None
        self._sql_datatype = None
        self._field_exclusions = None
        self._unsupported_description = None
        self._tap_google_analytics_cubes = None
        self._tap_google_analytics_group = None
        self._behavior = None
        self.discriminator = None

        if inclusion is not None:
            self.inclusion = inclusion
        if selected is not None:
            self.selected = selected
        if selected_by_default is not None:
            self.selected_by_default = selected_by_default
        if sql_datatype is not None:
            self.sql_datatype = sql_datatype
        if field_exclusions is not None:
            self.field_exclusions = field_exclusions
        if unsupported_description is not None:
            self.unsupported_description = unsupported_description
        if tap_google_analytics_cubes is not None:
            self.tap_google_analytics_cubes = tap_google_analytics_cubes
        if tap_google_analytics_group is not None:
            self.tap_google_analytics_group = tap_google_analytics_group
        if behavior is not None:
            self.behavior = behavior

    @property
    def inclusion(self):
        """Gets the inclusion of this FieldLevelMetadata.  # noqa: E501

        Indicates when a field will be included. Possible values are: automatic - The field is included all the time, regardless of selected-by-default and selected values available - The field is available for selection. The field will be included if selected-by-default or selected is true. unsupported - The field is unsupported and will not be included, regardless of selected-by-default and selected values If a field is unsupported, the `unsupported-description` attribute may provide additonal information.   # noqa: E501

        :return: The inclusion of this FieldLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._inclusion

    @inclusion.setter
    def inclusion(self, inclusion):
        """Sets the inclusion of this FieldLevelMetadata.

        Indicates when a field will be included. Possible values are: automatic - The field is included all the time, regardless of selected-by-default and selected values available - The field is available for selection. The field will be included if selected-by-default or selected is true. unsupported - The field is unsupported and will not be included, regardless of selected-by-default and selected values If a field is unsupported, the `unsupported-description` attribute may provide additonal information.   # noqa: E501

        :param inclusion: The inclusion of this FieldLevelMetadata.  # noqa: E501
        :type: str
        """
        allowed_values = ["automatic", "available", "unsupported"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and inclusion not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `inclusion` ({0}), must be one of {1}".format(  # noqa: E501
                    inclusion, allowed_values
                )
            )

        self._inclusion = inclusion

    @property
    def selected(self):
        """Gets the selected of this FieldLevelMetadata.  # noqa: E501

        Indicates whether a field should be included in a stream's field selection list. This value will be present only if the stream containing the field is selected (selected: true). null - The value has not been set true - The field is selected false - The field is not selected   # noqa: E501

        :return: The selected of this FieldLevelMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._selected

    @selected.setter
    def selected(self, selected):
        """Sets the selected of this FieldLevelMetadata.

        Indicates whether a field should be included in a stream's field selection list. This value will be present only if the stream containing the field is selected (selected: true). null - The value has not been set true - The field is selected false - The field is not selected   # noqa: E501

        :param selected: The selected of this FieldLevelMetadata.  # noqa: E501
        :type: bool
        """

        self._selected = selected

    @property
    def selected_by_default(self):
        """Gets the selected_by_default of this FieldLevelMetadata.  # noqa: E501

        Indicates if a field will be selected by default. Possible values are: null - The value has not been set true - The field is selected by default and is included regardless of the `selected` value false - The field is not selected by default. The field will be included if the `selected value` is true.   # noqa: E501

        :return: The selected_by_default of this FieldLevelMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._selected_by_default

    @selected_by_default.setter
    def selected_by_default(self, selected_by_default):
        """Sets the selected_by_default of this FieldLevelMetadata.

        Indicates if a field will be selected by default. Possible values are: null - The value has not been set true - The field is selected by default and is included regardless of the `selected` value false - The field is not selected by default. The field will be included if the `selected value` is true.   # noqa: E501

        :param selected_by_default: The selected_by_default of this FieldLevelMetadata.  # noqa: E501
        :type: bool
        """

        self._selected_by_default = selected_by_default

    @property
    def sql_datatype(self):
        """Gets the sql_datatype of this FieldLevelMetadata.  # noqa: E501

        For database sources only. The data type of a column from a database.   # noqa: E501

        :return: The sql_datatype of this FieldLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._sql_datatype

    @sql_datatype.setter
    def sql_datatype(self, sql_datatype):
        """Sets the sql_datatype of this FieldLevelMetadata.

        For database sources only. The data type of a column from a database.   # noqa: E501

        :param sql_datatype: The sql_datatype of this FieldLevelMetadata.  # noqa: E501
        :type: str
        """

        self._sql_datatype = sql_datatype

    @property
    def field_exclusions(self):
        """Gets the field_exclusions of this FieldLevelMetadata.  # noqa: E501

        A list of arrays, each array containing an array of strings that correspond to fields that are incompatible when the current field is selected. For example: If the metadata for a DeviceOS field contains a fieldExclusion of [\"properties\":\"ImpressionLostToBidPercent\"], then the DeviceOS and ImpressionLostToBidPercent fields cannot be selected together in the stream.   # noqa: E501

        :return: The field_exclusions of this FieldLevelMetadata.  # noqa: E501
        :rtype: object
        """
        return self._field_exclusions

    @field_exclusions.setter
    def field_exclusions(self, field_exclusions):
        """Sets the field_exclusions of this FieldLevelMetadata.

        A list of arrays, each array containing an array of strings that correspond to fields that are incompatible when the current field is selected. For example: If the metadata for a DeviceOS field contains a fieldExclusion of [\"properties\":\"ImpressionLostToBidPercent\"], then the DeviceOS and ImpressionLostToBidPercent fields cannot be selected together in the stream.   # noqa: E501

        :param field_exclusions: The field_exclusions of this FieldLevelMetadata.  # noqa: E501
        :type: object
        """

        self._field_exclusions = field_exclusions

    @property
    def unsupported_description(self):
        """Gets the unsupported_description of this FieldLevelMetadata.  # noqa: E501

        The reason a field is unsupported (`inclusion`: unsupported). Note: This is not available for all sources.   # noqa: E501

        :return: The unsupported_description of this FieldLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._unsupported_description

    @unsupported_description.setter
    def unsupported_description(self, unsupported_description):
        """Sets the unsupported_description of this FieldLevelMetadata.

        The reason a field is unsupported (`inclusion`: unsupported). Note: This is not available for all sources.   # noqa: E501

        :param unsupported_description: The unsupported_description of this FieldLevelMetadata.  # noqa: E501
        :type: str
        """

        self._unsupported_description = unsupported_description

    @property
    def tap_google_analytics_cubes(self):
        """Gets the tap_google_analytics_cubes of this FieldLevelMetadata.  # noqa: E501

        For Google Analytics sources only. An array of strings containing the ‘cubes' the field is a part of. A cube is a group of metrics and dimensions that are compatible together.   # noqa: E501

        :return: The tap_google_analytics_cubes of this FieldLevelMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._tap_google_analytics_cubes

    @tap_google_analytics_cubes.setter
    def tap_google_analytics_cubes(self, tap_google_analytics_cubes):
        """Sets the tap_google_analytics_cubes of this FieldLevelMetadata.

        For Google Analytics sources only. An array of strings containing the ‘cubes' the field is a part of. A cube is a group of metrics and dimensions that are compatible together.   # noqa: E501

        :param tap_google_analytics_cubes: The tap_google_analytics_cubes of this FieldLevelMetadata.  # noqa: E501
        :type: list[str]
        """

        self._tap_google_analytics_cubes = tap_google_analytics_cubes

    @property
    def tap_google_analytics_group(self):
        """Gets the tap_google_analytics_group of this FieldLevelMetadata.  # noqa: E501

        For Google Analytics sources only. The group the field belongs to. Possible values are: - Ad Exchange - Adsense - Adwords - App Tracking - Audience - Channel Grouping - Content Experiments - Content Grouping - Custom Variables or Columns - DoubleClick Bid Manager - DoubleClick Campaign Manager - DoubleClick Search - DoubleClick for Publishers - DoubleClick for Publishers Backfill - Ecommerce - Event Tracking - Exceptions - Geo Network - Goal Conversions - Internal Search - Lifetime Value and Cohorts - Page Tracking - Platform or Device - Publisher - Report Fields - Session - Site Speed - Social Activities - Social Interactions - System - Time - Traffic Sources - User - User Timings   # noqa: E501

        :return: The tap_google_analytics_group of this FieldLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._tap_google_analytics_group

    @tap_google_analytics_group.setter
    def tap_google_analytics_group(self, tap_google_analytics_group):
        """Sets the tap_google_analytics_group of this FieldLevelMetadata.

        For Google Analytics sources only. The group the field belongs to. Possible values are: - Ad Exchange - Adsense - Adwords - App Tracking - Audience - Channel Grouping - Content Experiments - Content Grouping - Custom Variables or Columns - DoubleClick Bid Manager - DoubleClick Campaign Manager - DoubleClick Search - DoubleClick for Publishers - DoubleClick for Publishers Backfill - Ecommerce - Event Tracking - Exceptions - Geo Network - Goal Conversions - Internal Search - Lifetime Value and Cohorts - Page Tracking - Platform or Device - Publisher - Report Fields - Session - Site Speed - Social Activities - Social Interactions - System - Time - Traffic Sources - User - User Timings   # noqa: E501

        :param tap_google_analytics_group: The tap_google_analytics_group of this FieldLevelMetadata.  # noqa: E501
        :type: str
        """

        self._tap_google_analytics_group = tap_google_analytics_group

    @property
    def behavior(self):
        """Gets the behavior of this FieldLevelMetadata.  # noqa: E501

        For Google Analytics and Google Ads sources only. The type of field. Possible values are: - ATTRIBUTE - Goolgle Ads sources only - METRIC - DIMENSION - Google Analytics sources only - SEGMENT - Goolgle Ads sources only Note: This property won't be present for Google Analytics fields where tap_google_analytics.group: Report Fields.   # noqa: E501

        :return: The behavior of this FieldLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._behavior

    @behavior.setter
    def behavior(self, behavior):
        """Sets the behavior of this FieldLevelMetadata.

        For Google Analytics and Google Ads sources only. The type of field. Possible values are: - ATTRIBUTE - Goolgle Ads sources only - METRIC - DIMENSION - Google Analytics sources only - SEGMENT - Goolgle Ads sources only Note: This property won't be present for Google Analytics fields where tap_google_analytics.group: Report Fields.   # noqa: E501

        :param behavior: The behavior of this FieldLevelMetadata.  # noqa: E501
        :type: str
        """

        self._behavior = behavior

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FieldLevelMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FieldLevelMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class CreateSourceBody(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "display_name": "str",
        "type": "str",
        "name": "str",
        "properties": "SourceFormProperties",
        "destination_id": "integer",
    }

    attribute_map = {
        "display_name": "display_name",
        "type": "type",
        "name": "name",
        "properties": "properties",
        "destination_id": "destination_id",
    }

    def __init__(
        self,
        display_name=None,
        type=None,
        name=None,
        properties=None,
        local_vars_configuration=None,
        destination_id=None,
    ):  # noqa: E501
        """CreateSourceBody - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._display_name = None
        self._type = None
        self._name = None
        self._properties = None
        self.discriminator = None
        self.destination_id = None

        self.display_name = display_name
        self.type = type
        if name is not None:
            self.name = name
        if properties is not None:
            self.properties = properties

    @property
    def display_name(self):
        """Gets the display_name of this CreateSourceBody.  # noqa: E501

        A descriptive name for the source. This will be used to dynamically generate the name corresponding to the schema name or dataset name that the data from this source will be loaded into.   # noqa: E501

        :return: The display_name of this CreateSourceBody.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this CreateSourceBody.

        A descriptive name for the source. This will be used to dynamically generate the name corresponding to the schema name or dataset name that the data from this source will be loaded into.   # noqa: E501

        :param display_name: The display_name of this CreateSourceBody.  # noqa: E501
        :type: str
        """
        if (
            self.local_vars_configuration.client_side_validation
            and display_name is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `display_name`, must not be `None`"
            )  # noqa: E501

        self._display_name = display_name

    @property
    def type(self):
        """Gets the type of this CreateSourceBody.  # noqa: E501

        The source type. For example: platform.marketo or platform.hubspot.   # noqa: E501

        :return: The type of this CreateSourceBody.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateSourceBody.

        The source type. For example: platform.marketo or platform.hubspot.   # noqa: E501

        :param type: The type of this CreateSourceBody.  # noqa: E501
        :type: str
        """
        if (
            self.local_vars_configuration.client_side_validation and type is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501

        self._type = type

    @property
    def name(self):
        """Gets the name of this CreateSourceBody.  # noqa: E501

        The destination schema name that the data from this source will be loaded into. Names must: - Contain only lowercase alphanumerics and underscores - Be unique within each Stitch client account   # noqa: E501

        :return: The name of this CreateSourceBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateSourceBody.

        The destination schema name that the data from this source will be loaded into. Names must: - Contain only lowercase alphanumerics and underscores - Be unique within each Stitch client account   # noqa: E501

        :param name: The name of this CreateSourceBody.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def properties(self):
        """Gets the properties of this CreateSourceBody.  # noqa: E501


        :return: The properties of this CreateSourceBody.  # noqa: E501
        :rtype: SourceFormProperties
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this CreateSourceBody.


        :param properties: The properties of this CreateSourceBody.  # noqa: E501
        :type: SourceFormProperties
        """

        self._properties = properties

    @property
    def destination_id(self):
        """Gets the destination_id of this CreateSourceBody.  # noqa: E501


        :return: The destination_id of this CreateSourceBody.  # noqa: E501
        :rtype: integer
        """
        return self.destination_id

    @properties.setter
    def destination_id(self, destination_id):
        """Sets the destination_id of this CreateSourceBody.


        :param destination_id: The destination_id  this CreateSourceBody.  # noqa: E501
        :type: integer
        """

        self.destination_id = destination_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateSourceBody):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateSourceBody):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class StreamLevelMetadata(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "database_name": "str",
        "forced_replication_method": "ForcedReplicationMethod",
        "is_view": "bool",
        "replication_key": "str",
        "replication_method": "str",
        "row_count": "int",
        "schema_name": "str",
        "selected": "bool",
        "table_key_properties": "list[str]",
        "valid_replication_keys": "list[str]",
        "view_key_properties": "list[str]",
        "tap_google_analytics_all_cubes": "list[str]",
    }

    attribute_map = {
        "database_name": "database-name",
        "forced_replication_method": "forced-replication-method",
        "is_view": "is-view",
        "replication_key": "replication-key",
        "replication_method": "replication-method",
        "row_count": "row-count",
        "schema_name": "schema-name",
        "selected": "selected",
        "table_key_properties": "table-key-properties",
        "valid_replication_keys": "valid-replication-keys",
        "view_key_properties": "view-key-properties",
        "tap_google_analytics_all_cubes": "tap_google_analytics.all_cubes",
    }

    def __init__(
        self,
        database_name=None,
        forced_replication_method=None,
        is_view=None,
        replication_key=None,
        replication_method=None,
        row_count=None,
        schema_name=None,
        selected=None,
        table_key_properties=None,
        valid_replication_keys=None,
        view_key_properties=None,
        tap_google_analytics_all_cubes=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """StreamLevelMetadata - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._database_name = None
        self._forced_replication_method = None
        self._is_view = None
        self._replication_key = None
        self._replication_method = None
        self._row_count = None
        self._schema_name = None
        self._selected = None
        self._table_key_properties = None
        self._valid_replication_keys = None
        self._view_key_properties = None
        self._tap_google_analytics_all_cubes = None
        self.discriminator = None

        if database_name is not None:
            self.database_name = database_name
        if forced_replication_method is not None:
            self.forced_replication_method = forced_replication_method
        if is_view is not None:
            self.is_view = is_view
        if replication_key is not None:
            self.replication_key = replication_key
        if replication_method is not None:
            self.replication_method = replication_method
        if row_count is not None:
            self.row_count = row_count
        if schema_name is not None:
            self.schema_name = schema_name
        if selected is not None:
            self.selected = selected
        if table_key_properties is not None:
            self.table_key_properties = table_key_properties
        if valid_replication_keys is not None:
            self.valid_replication_keys = valid_replication_keys
        if view_key_properties is not None:
            self.view_key_properties = view_key_properties
        if tap_google_analytics_all_cubes is not None:
            self.tap_google_analytics_all_cubes = tap_google_analytics_all_cubes

    @property
    def database_name(self):
        """Gets the database_name of this StreamLevelMetadata.  # noqa: E501

        For database sources only. The name of the database containing the stream.   # noqa: E501

        :return: The database_name of this StreamLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._database_name

    @database_name.setter
    def database_name(self, database_name):
        """Sets the database_name of this StreamLevelMetadata.

        For database sources only. The name of the database containing the stream.   # noqa: E501

        :param database_name: The database_name of this StreamLevelMetadata.  # noqa: E501
        :type: str
        """

        self._database_name = database_name

    @property
    def forced_replication_method(self):
        """Gets the forced_replication_method of this StreamLevelMetadata.  # noqa: E501


        :return: The forced_replication_method of this StreamLevelMetadata.  # noqa: E501
        :rtype: ForcedReplicationMethod
        """
        return self._forced_replication_method

    @forced_replication_method.setter
    def forced_replication_method(self, forced_replication_method):
        """Sets the forced_replication_method of this StreamLevelMetadata.


        :param forced_replication_method: The forced_replication_method of this StreamLevelMetadata.  # noqa: E501
        :type: ForcedReplicationMethod
        """

        self._forced_replication_method = forced_replication_method

    @property
    def is_view(self):
        """Gets the is_view of this StreamLevelMetadata.  # noqa: E501

        For database sources only. Indicates if the stream is a database view.   # noqa: E501

        :return: The is_view of this StreamLevelMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._is_view

    @is_view.setter
    def is_view(self, is_view):
        """Sets the is_view of this StreamLevelMetadata.

        For database sources only. Indicates if the stream is a database view.   # noqa: E501

        :param is_view: The is_view of this StreamLevelMetadata.  # noqa: E501
        :type: bool
        """

        self._is_view = is_view

    @property
    def replication_key(self):
        """Gets the replication_key of this StreamLevelMetadata.  # noqa: E501

        Indicates the field being used as the stream's Replication Key.   # noqa: E501

        :return: The replication_key of this StreamLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._replication_key

    @replication_key.setter
    def replication_key(self, replication_key):
        """Sets the replication_key of this StreamLevelMetadata.

        Indicates the field being used as the stream's Replication Key.   # noqa: E501

        :param replication_key: The replication_key of this StreamLevelMetadata.  # noqa: E501
        :type: str
        """

        self._replication_key = replication_key

    @property
    def replication_method(self):
        """Gets the replication_method of this StreamLevelMetadata.  # noqa: E501

        The Replication Method the stream uses to replicate data. Accepted values are: FULL_TABLE - The stream is using Full Table Replication INCREMENTAL - The stream is using Key-based Incremental Replication LOG_BASED - The stream is using Log-based Incremental Replication. Note: This method is only available for certain database sources, and requires additional setup to use.   # noqa: E501

        :return: The replication_method of this StreamLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._replication_method

    @replication_method.setter
    def replication_method(self, replication_method):
        """Sets the replication_method of this StreamLevelMetadata.

        The Replication Method the stream uses to replicate data. Accepted values are: FULL_TABLE - The stream is using Full Table Replication INCREMENTAL - The stream is using Key-based Incremental Replication LOG_BASED - The stream is using Log-based Incremental Replication. Note: This method is only available for certain database sources, and requires additional setup to use.   # noqa: E501

        :param replication_method: The replication_method of this StreamLevelMetadata.  # noqa: E501
        :type: str
        """
        allowed_values = ["FULL_TABLE", "INCREMENTAL", "LOG_BASED"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and replication_method not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `replication_method` ({0}), must be one of {1}".format(  # noqa: E501
                    replication_method, allowed_values
                )
            )

        self._replication_method = replication_method

    @property
    def row_count(self):
        """Gets the row_count of this StreamLevelMetadata.  # noqa: E501

        For database sources only. The number of rows (records) in the stream.   # noqa: E501

        :return: The row_count of this StreamLevelMetadata.  # noqa: E501
        :rtype: int
        """
        return self._row_count

    @row_count.setter
    def row_count(self, row_count):
        """Sets the row_count of this StreamLevelMetadata.

        For database sources only. The number of rows (records) in the stream.   # noqa: E501

        :param row_count: The row_count of this StreamLevelMetadata.  # noqa: E501
        :type: int
        """

        self._row_count = row_count

    @property
    def schema_name(self):
        """Gets the schema_name of this StreamLevelMetadata.  # noqa: E501

        For database sources only. The name of the schema containing the stream.   # noqa: E501

        :return: The schema_name of this StreamLevelMetadata.  # noqa: E501
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """Sets the schema_name of this StreamLevelMetadata.

        For database sources only. The name of the schema containing the stream.   # noqa: E501

        :param schema_name: The schema_name of this StreamLevelMetadata.  # noqa: E501
        :type: str
        """

        self._schema_name = schema_name

    @property
    def selected(self):
        """Gets the selected of this StreamLevelMetadata.  # noqa: E501

        Indicates whether a stream should be set to replicate. Accepted values are: true - The stream is selected and data for selected fields will be replicated false - The stream is not selected and no data will be replicated   # noqa: E501

        :return: The selected of this StreamLevelMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._selected

    @selected.setter
    def selected(self, selected):
        """Sets the selected of this StreamLevelMetadata.

        Indicates whether a stream should be set to replicate. Accepted values are: true - The stream is selected and data for selected fields will be replicated false - The stream is not selected and no data will be replicated   # noqa: E501

        :param selected: The selected of this StreamLevelMetadata.  # noqa: E501
        :type: bool
        """

        self._selected = selected

    @property
    def table_key_properties(self):
        """Gets the table_key_properties of this StreamLevelMetadata.  # noqa: E501

        An array of strings listing the fields that make up the key properties of the table. These are the table's defined Primary Keys.   # noqa: E501

        :return: The table_key_properties of this StreamLevelMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._table_key_properties

    @table_key_properties.setter
    def table_key_properties(self, table_key_properties):
        """Sets the table_key_properties of this StreamLevelMetadata.

        An array of strings listing the fields that make up the key properties of the table. These are the table's defined Primary Keys.   # noqa: E501

        :param table_key_properties: The table_key_properties of this StreamLevelMetadata.  # noqa: E501
        :type: list[str]
        """

        self._table_key_properties = table_key_properties

    @property
    def valid_replication_keys(self):
        """Gets the valid_replication_keys of this StreamLevelMetadata.  # noqa: E501

        An array of strings indicating the fields valid for use as Replication Keys in Key-based Incremental Replication (replication-method: INCREMENTAL). Note: For SaaS sources, the fields listed in this array are pre-defined by Stitch and will be used as the Replication Keys for the stream. They cannot be modified.   # noqa: E501

        :return: The valid_replication_keys of this StreamLevelMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._valid_replication_keys

    @valid_replication_keys.setter
    def valid_replication_keys(self, valid_replication_keys):
        """Sets the valid_replication_keys of this StreamLevelMetadata.

        An array of strings indicating the fields valid for use as Replication Keys in Key-based Incremental Replication (replication-method: INCREMENTAL). Note: For SaaS sources, the fields listed in this array are pre-defined by Stitch and will be used as the Replication Keys for the stream. They cannot be modified.   # noqa: E501

        :param valid_replication_keys: The valid_replication_keys of this StreamLevelMetadata.  # noqa: E501
        :type: list[str]
        """

        self._valid_replication_keys = valid_replication_keys

    @property
    def view_key_properties(self):
        """Gets the view_key_properties of this StreamLevelMetadata.  # noqa: E501

        For database sources only. An array of strings listing the fields that make up the key properties of the view.   # noqa: E501

        :return: The view_key_properties of this StreamLevelMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._view_key_properties

    @view_key_properties.setter
    def view_key_properties(self, view_key_properties):
        """Sets the view_key_properties of this StreamLevelMetadata.

        For database sources only. An array of strings listing the fields that make up the key properties of the view.   # noqa: E501

        :param view_key_properties: The view_key_properties of this StreamLevelMetadata.  # noqa: E501
        :type: list[str]
        """

        self._view_key_properties = view_key_properties

    @property
    def tap_google_analytics_all_cubes(self):
        """Gets the tap_google_analytics_all_cubes of this StreamLevelMetadata.  # noqa: E501

        For Google Analytics sources only. An array of strings listing all the ‘cubes' available in the Google Analytics source. A cube is a group of metrics and dimensions that are compatible together.   # noqa: E501

        :return: The tap_google_analytics_all_cubes of this StreamLevelMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._tap_google_analytics_all_cubes

    @tap_google_analytics_all_cubes.setter
    def tap_google_analytics_all_cubes(self, tap_google_analytics_all_cubes):
        """Sets the tap_google_analytics_all_cubes of this StreamLevelMetadata.

        For Google Analytics sources only. An array of strings listing all the ‘cubes' available in the Google Analytics source. A cube is a group of metrics and dimensions that are compatible together.   # noqa: E501

        :param tap_google_analytics_all_cubes: The tap_google_analytics_all_cubes of this StreamLevelMetadata.  # noqa: E501
        :type: list[str]
        """

        self._tap_google_analytics_all_cubes = tap_google_analytics_all_cubes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StreamLevelMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StreamLevelMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class Source(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "id": "int",
        "created_at": "str",
        "deleted_at": "str",
        "display_name": "str",
        "name": "str",
        "paused_at": "str",
        "properties": "SourceFormProperties",
        "report_card": "SourceReportCard",
        "stitch_client_id": "int",
        "system_paused_at": "str",
        "type": "str",
        "updated_at": "str",
    }

    attribute_map = {
        "id": "id",
        "created_at": "created_at",
        "deleted_at": "deleted_at",
        "display_name": "display_name",
        "name": "name",
        "paused_at": "paused_at",
        "properties": "properties",
        "report_card": "report_card",
        "stitch_client_id": "stitch_client_id",
        "system_paused_at": "system_paused_at",
        "type": "type",
        "updated_at": "updated_at",
    }

    def __init__(
        self,
        id=None,
        created_at=None,
        deleted_at=None,
        display_name=None,
        name=None,
        paused_at=None,
        properties=None,
        report_card=None,
        stitch_client_id=None,
        system_paused_at=None,
        type=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Source - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_at = None
        self._deleted_at = None
        self._display_name = None
        self._name = None
        self._paused_at = None
        self._properties = None
        self._report_card = None
        self._stitch_client_id = None
        self._system_paused_at = None
        self._type = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if deleted_at is not None:
            self.deleted_at = deleted_at
        if display_name is not None:
            self.display_name = display_name
        if name is not None:
            self.name = name
        if paused_at is not None:
            self.paused_at = paused_at
        if properties is not None:
            self.properties = properties
        if report_card is not None:
            self.report_card = report_card
        if stitch_client_id is not None:
            self.stitch_client_id = stitch_client_id
        if system_paused_at is not None:
            self.system_paused_at = system_paused_at
        if type is not None:
            self.type = type
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this Source.  # noqa: E501

        The unique identifier for this source.  # noqa: E501

        :return: The id of this Source.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Source.

        The unique identifier for this source.  # noqa: E501

        :param id: The id of this Source.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Source.  # noqa: E501

        The time at which the source object was created.  # noqa: E501

        :return: The created_at of this Source.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Source.

        The time at which the source object was created.  # noqa: E501

        :param created_at: The created_at of this Source.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def deleted_at(self):
        """Gets the deleted_at of this Source.  # noqa: E501

        The time at which the source object was deleted.  # noqa: E501

        :return: The deleted_at of this Source.  # noqa: E501
        :rtype: str
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this Source.

        The time at which the source object was deleted.  # noqa: E501

        :param deleted_at: The deleted_at of this Source.  # noqa: E501
        :type: str
        """

        self._deleted_at = deleted_at

    @property
    def display_name(self):
        """Gets the display_name of this Source.  # noqa: E501

        The display name of the source connection.  # noqa: E501

        :return: The display_name of this Source.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Source.

        The display name of the source connection.  # noqa: E501

        :param display_name: The display_name of this Source.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def name(self):
        """Gets the name of this Source.  # noqa: E501

        The name of the source connection, dynamically generated from `display_name`. The `name` corresponds to the destination schema name that the data from this source will be loaded into. Names must: - Contain only lowercase alphanumerics and underscores - Be unique within each Stitch client account   # noqa: E501

        :return: The name of this Source.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Source.

        The name of the source connection, dynamically generated from `display_name`. The `name` corresponds to the destination schema name that the data from this source will be loaded into. Names must: - Contain only lowercase alphanumerics and underscores - Be unique within each Stitch client account   # noqa: E501

        :param name: The name of this Source.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def paused_at(self):
        """Gets the paused_at of this Source.  # noqa: E501

        If the connection was paused by the user, the time the pause began. Otherwise, or if the connection is active, this will be `null`.   # noqa: E501

        :return: The paused_at of this Source.  # noqa: E501
        :rtype: str
        """
        return self._paused_at

    @paused_at.setter
    def paused_at(self, paused_at):
        """Sets the paused_at of this Source.

        If the connection was paused by the user, the time the pause began. Otherwise, or if the connection is active, this will be `null`.   # noqa: E501

        :param paused_at: The paused_at of this Source.  # noqa: E501
        :type: str
        """

        self._paused_at = paused_at

    @property
    def properties(self):
        """Gets the properties of this Source.  # noqa: E501


        :return: The properties of this Source.  # noqa: E501
        :rtype: SourceFormProperties
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this Source.


        :param properties: The properties of this Source.  # noqa: E501
        :type: SourceFormProperties
        """

        self._properties = properties

    @property
    def report_card(self):
        """Gets the report_card of this Source.  # noqa: E501


        :return: The report_card of this Source.  # noqa: E501
        :rtype: SourceReportCard
        """
        return self._report_card

    @report_card.setter
    def report_card(self, report_card):
        """Sets the report_card of this Source.


        :param report_card: The report_card of this Source.  # noqa: E501
        :type: SourceReportCard
        """

        self._report_card = report_card

    @property
    def stitch_client_id(self):
        """Gets the stitch_client_id of this Source.  # noqa: E501

        The ID of the Stitch client account.  # noqa: E501

        :return: The stitch_client_id of this Source.  # noqa: E501
        :rtype: int
        """
        return self._stitch_client_id

    @stitch_client_id.setter
    def stitch_client_id(self, stitch_client_id):
        """Sets the stitch_client_id of this Source.

        The ID of the Stitch client account.  # noqa: E501

        :param stitch_client_id: The stitch_client_id of this Source.  # noqa: E501
        :type: int
        """

        self._stitch_client_id = stitch_client_id

    @property
    def system_paused_at(self):
        """Gets the system_paused_at of this Source.  # noqa: E501

        If the connection was paused by the system, the time the pause began. Otherwise, or if the connection is active, this will be null.   # noqa: E501

        :return: The system_paused_at of this Source.  # noqa: E501
        :rtype: str
        """
        return self._system_paused_at

    @system_paused_at.setter
    def system_paused_at(self, system_paused_at):
        """Sets the system_paused_at of this Source.

        If the connection was paused by the system, the time the pause began. Otherwise, or if the connection is active, this will be null.   # noqa: E501

        :param system_paused_at: The system_paused_at of this Source.  # noqa: E501
        :type: str
        """

        self._system_paused_at = system_paused_at

    @property
    def type(self):
        """Gets the type of this Source.  # noqa: E501

        The source type.  # noqa: E501

        :return: The type of this Source.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Source.

        The source type.  # noqa: E501

        :param type: The type of this Source.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def updated_at(self):
        """Gets the updated_at of this Source.  # noqa: E501

        The time at which the object was last updated.  # noqa: E501

        :return: The updated_at of this Source.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Source.

        The time at which the object was last updated.  # noqa: E501

        :param updated_at: The updated_at of this Source.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Source):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Source):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class UpdateSourceBody(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "display_name": "str",
        "paused_at": "str",
        "properties": "SourceFormProperties",
    }

    attribute_map = {
        "display_name": "display_name",
        "paused_at": "paused_at",
        "properties": "properties",
    }

    def __init__(
        self,
        display_name=None,
        paused_at=None,
        properties=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """UpdateSourceBody - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._display_name = None
        self._paused_at = None
        self._properties = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        if paused_at is not None:
            self.paused_at = paused_at
        if properties is not None:
            self.properties = properties

    @property
    def display_name(self):
        """Gets the display_name of this UpdateSourceBody.  # noqa: E501

        A descriptive name for the source. This will be used to dynamically generate the name corresponding to the schema name or dataset name that the data from this source will be loaded into.   # noqa: E501

        :return: The display_name of this UpdateSourceBody.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this UpdateSourceBody.

        A descriptive name for the source. This will be used to dynamically generate the name corresponding to the schema name or dataset name that the data from this source will be loaded into.   # noqa: E501

        :param display_name: The display_name of this UpdateSourceBody.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def paused_at(self):
        """Gets the paused_at of this UpdateSourceBody.  # noqa: E501

        The time the source was paused. This field must contain an ISO 8601-compliant date. Note: Providing any value - past, present, or future - for this property will pause the source immediately if the request is successful.   # noqa: E501

        :return: The paused_at of this UpdateSourceBody.  # noqa: E501
        :rtype: str
        """
        return self._paused_at

    @paused_at.setter
    def paused_at(self, paused_at):
        """Sets the paused_at of this UpdateSourceBody.

        The time the source was paused. This field must contain an ISO 8601-compliant date. Note: Providing any value - past, present, or future - for this property will pause the source immediately if the request is successful.   # noqa: E501

        :param paused_at: The paused_at of this UpdateSourceBody.  # noqa: E501
        :type: str
        """

        self._paused_at = paused_at

    @property
    def properties(self):
        """Gets the properties of this UpdateSourceBody.  # noqa: E501


        :return: The properties of this UpdateSourceBody.  # noqa: E501
        :rtype: SourceFormProperties
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this UpdateSourceBody.


        :param properties: The properties of this UpdateSourceBody.  # noqa: E501
        :type: SourceFormProperties
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSourceBody):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateSourceBody):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class ConnectionStep(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"type": "str", "properties": "list[ConnectionStepProps]"}

    attribute_map = {"type": "type", "properties": "properties"}

    def __init__(
        self, type=None, properties=None, local_vars_configuration=None
    ):  # noqa: E501
        """ConnectionStep - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._properties = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if properties is not None:
            self.properties = properties

    @property
    def type(self):
        """Gets the type of this ConnectionStep.  # noqa: E501

        The type of step  # noqa: E501

        :return: The type of this ConnectionStep.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ConnectionStep.

        The type of step  # noqa: E501

        :param type: The type of this ConnectionStep.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "form",
            "oauth",
            "profile",
            "discover_schema",
            "field_selection",
            "fully_configured",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and type not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    @property
    def properties(self):
        """Gets the properties of this ConnectionStep.  # noqa: E501

        The destination connection type. For example: postgres or redshift   # noqa: E501

        :return: The properties of this ConnectionStep.  # noqa: E501
        :rtype: list[ConnectionStepProps]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this ConnectionStep.

        The destination connection type. For example: postgres or redshift   # noqa: E501

        :param properties: The properties of this ConnectionStep.  # noqa: E501
        :type: list[ConnectionStepProps]
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectionStep):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectionStep):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class GoogleAnalyticsSourceFormProperties(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "anchor_time": "str",
        "client_id": "str",
        "client_secret": "str",
        "cron_expression": "str",
        "frequency_in_minutes": "str",
        "quota_user": "str",
        "refresh_token": "str",
        "report_definitions": "list[GoogleAnalyticsSourceFormPropertiesReportDefinitions]",
        "start_date": "str",
    }

    attribute_map = {
        "anchor_time": "anchor_time",
        "client_id": "client_id",
        "client_secret": "client_secret",
        "cron_expression": "cron_expression",
        "frequency_in_minutes": "frequency_in_minutes",
        "quota_user": "quota_user",
        "refresh_token": "refresh_token",
        "report_definitions": "report_definitions",
        "start_date": "start_date",
    }

    def __init__(
        self,
        anchor_time=None,
        client_id=None,
        client_secret=None,
        cron_expression=None,
        frequency_in_minutes=None,
        quota_user=None,
        refresh_token=None,
        report_definitions=None,
        start_date=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """GoogleAnalyticsSourceFormProperties - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._anchor_time = None
        self._client_id = None
        self._client_secret = None
        self._cron_expression = None
        self._frequency_in_minutes = None
        self._quota_user = None
        self._refresh_token = None
        self._report_definitions = None
        self._start_date = None
        self.discriminator = None

        if anchor_time is not None:
            self.anchor_time = anchor_time
        if client_id is not None:
            self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if cron_expression is not None:
            self.cron_expression = cron_expression
        if frequency_in_minutes is not None:
            self.frequency_in_minutes = frequency_in_minutes
        if quota_user is not None:
            self.quota_user = quota_user
        if refresh_token is not None:
            self.refresh_token = refresh_token
        if report_definitions is not None:
            self.report_definitions = report_definitions
        if start_date is not None:
            self.start_date = start_date

    @property
    def anchor_time(self):
        """Gets the anchor_time of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        Defines the time that frequency_in_minutes is \"anchored\" to, which Stitch will use to create the integration's replication schedule. In Stitch, this is referred to as Anchor Scheduling. This field must contain an ISO 8601-compliant date. Note: When Stitch stores this value, it will be in UTC. You should provide this value in UTC to ensure the desired anchor time is retained. For example: You want to create a schedule that is anchored to 1:00PM EST and runs every 6 hours (360 minutes). To do this, you can set anchor_time to something like 2018-04-30T17:00:00Z and frequency_in_minutes to 360. This means jobs would run at 23:00:00, 05:00:00, 11:00:00, and so on.   # noqa: E501

        :return: The anchor_time of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._anchor_time

    @anchor_time.setter
    def anchor_time(self, anchor_time):
        """Sets the anchor_time of this GoogleAnalyticsSourceFormProperties.

        Defines the time that frequency_in_minutes is \"anchored\" to, which Stitch will use to create the integration's replication schedule. In Stitch, this is referred to as Anchor Scheduling. This field must contain an ISO 8601-compliant date. Note: When Stitch stores this value, it will be in UTC. You should provide this value in UTC to ensure the desired anchor time is retained. For example: You want to create a schedule that is anchored to 1:00PM EST and runs every 6 hours (360 minutes). To do this, you can set anchor_time to something like 2018-04-30T17:00:00Z and frequency_in_minutes to 360. This means jobs would run at 23:00:00, 05:00:00, 11:00:00, and so on.   # noqa: E501

        :param anchor_time: The anchor_time of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: str
        """

        self._anchor_time = anchor_time

    @property
    def client_id(self):
        """Gets the client_id of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        The secure OAuth 2.0 identifier for the client application.   # noqa: E501

        :return: The client_id of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this GoogleAnalyticsSourceFormProperties.

        The secure OAuth 2.0 identifier for the client application.   # noqa: E501

        :param client_id: The client_id of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        The secure OAuth 2.0 secret key for the client application.   # noqa: E501

        :return: The client_secret of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this GoogleAnalyticsSourceFormProperties.

        The secure OAuth 2.0 secret key for the client application.   # noqa: E501

        :param client_secret: The client_secret of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def cron_expression(self):
        """Gets the cron_expression of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        Note: Advanced Scheduling using Cron is not yet supported for this source. A value may be submitted for this property if the account is on an Enterprise plan, but Stitch will not use the expression submitted. A valid Quartz cron expression representing the replication schedule for the integration. Refer to the Advanced Scheduling documentation for more info. Note: If neither a cron_expression or frequency_in_minutes property is provided, Stitch will use the source's default frequency_in_minutes value (60).   # noqa: E501

        :return: The cron_expression of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._cron_expression

    @cron_expression.setter
    def cron_expression(self, cron_expression):
        """Sets the cron_expression of this GoogleAnalyticsSourceFormProperties.

        Note: Advanced Scheduling using Cron is not yet supported for this source. A value may be submitted for this property if the account is on an Enterprise plan, but Stitch will not use the expression submitted. A valid Quartz cron expression representing the replication schedule for the integration. Refer to the Advanced Scheduling documentation for more info. Note: If neither a cron_expression or frequency_in_minutes property is provided, Stitch will use the source's default frequency_in_minutes value (60).   # noqa: E501

        :param cron_expression: The cron_expression of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: str
        """

        self._cron_expression = cron_expression

    @property
    def frequency_in_minutes(self):
        """Gets the frequency_in_minutes of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        Defines how often, in minutes, Stitch should attempt to replicate data from Google Analytics. Accepted values are: - 30 - 60 - 360 - 720 - 1440   # noqa: E501

        :return: The frequency_in_minutes of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._frequency_in_minutes

    @frequency_in_minutes.setter
    def frequency_in_minutes(self, frequency_in_minutes):
        """Sets the frequency_in_minutes of this GoogleAnalyticsSourceFormProperties.

        Defines how often, in minutes, Stitch should attempt to replicate data from Google Analytics. Accepted values are: - 30 - 60 - 360 - 720 - 1440   # noqa: E501

        :param frequency_in_minutes: The frequency_in_minutes of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: str
        """

        self._frequency_in_minutes = frequency_in_minutes

    @property
    def quota_user(self):
        """Gets the quota_user of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        Note: This is a read-only property and will be returned when the Google Analytics object is successfully created. Including it in POST or PUT requests will result in InvalidProperties errors.   # noqa: E501

        :return: The quota_user of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._quota_user

    @quota_user.setter
    def quota_user(self, quota_user):
        """Sets the quota_user of this GoogleAnalyticsSourceFormProperties.

        Note: This is a read-only property and will be returned when the Google Analytics object is successfully created. Including it in POST or PUT requests will result in InvalidProperties errors.   # noqa: E501

        :param quota_user: The quota_user of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: str
        """

        self._quota_user = quota_user

    @property
    def refresh_token(self):
        """Gets the refresh_token of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        The OAuth 2.0 refresh token used to access the Google API.  # noqa: E501

        :return: The refresh_token of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this GoogleAnalyticsSourceFormProperties.

        The OAuth 2.0 refresh token used to access the Google API.  # noqa: E501

        :param refresh_token: The refresh_token of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: str
        """

        self._refresh_token = refresh_token

    @property
    def report_definitions(self):
        """Gets the report_definitions of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        An array of objects, each object pertaining to a custom report you want to create. Note: Metrics and dimensions for each report can be selected when the source proceeds to the field_selection step.   # noqa: E501

        :return: The report_definitions of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: list[GoogleAnalyticsSourceFormPropertiesReportDefinitions]
        """
        return self._report_definitions

    @report_definitions.setter
    def report_definitions(self, report_definitions):
        """Sets the report_definitions of this GoogleAnalyticsSourceFormProperties.

        An array of objects, each object pertaining to a custom report you want to create. Note: Metrics and dimensions for each report can be selected when the source proceeds to the field_selection step.   # noqa: E501

        :param report_definitions: The report_definitions of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: list[GoogleAnalyticsSourceFormPropertiesReportDefinitions]
        """

        self._report_definitions = report_definitions

    @property
    def start_date(self):
        """Gets the start_date of this GoogleAnalyticsSourceFormProperties.  # noqa: E501

        The date from which Stitch should begin replicating data from Salesforce. Data from this date forward will be replicated. This field must contain an ISO 8601-compliant date, and the timestamp must be midnight. For example: 2018-01-01T00:00:00Z   # noqa: E501

        :return: The start_date of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this GoogleAnalyticsSourceFormProperties.

        The date from which Stitch should begin replicating data from Salesforce. Data from this date forward will be replicated. This field must contain an ISO 8601-compliant date, and the timestamp must be midnight. For example: 2018-01-01T00:00:00Z   # noqa: E501

        :param start_date: The start_date of this GoogleAnalyticsSourceFormProperties.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GoogleAnalyticsSourceFormProperties):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GoogleAnalyticsSourceFormProperties):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class SourceReportCard(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "current_step": "int",
        "details": "ConnectionDetails",
        "steps": "list[ConnectionStep]",
        "type": "str",
    }

    attribute_map = {
        "current_step": "current_step",
        "details": "details",
        "steps": "steps",
        "type": "type",
    }

    def __init__(
        self,
        current_step=None,
        details=None,
        steps=None,
        type=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SourceReportCard - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._current_step = None
        self._details = None
        self._steps = None
        self._type = None
        self.discriminator = None

        if current_step is not None:
            self.current_step = current_step
        if details is not None:
            self.details = details
        if steps is not None:
            self.steps = steps
        if type is not None:
            self.type = type

    @property
    def current_step(self):
        """Gets the current_step of this SourceReportCard.  # noqa: E501

        The index (in the steps array) of the current step needed to configure the data source.   # noqa: E501

        :return: The current_step of this SourceReportCard.  # noqa: E501
        :rtype: int
        """
        return self._current_step

    @current_step.setter
    def current_step(self, current_step):
        """Sets the current_step of this SourceReportCard.

        The index (in the steps array) of the current step needed to configure the data source.   # noqa: E501

        :param current_step: The current_step of this SourceReportCard.  # noqa: E501
        :type: int
        """

        self._current_step = current_step

    @property
    def details(self):
        """Gets the details of this SourceReportCard.  # noqa: E501


        :return: The details of this SourceReportCard.  # noqa: E501
        :rtype: ConnectionDetails
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this SourceReportCard.


        :param details: The details of this SourceReportCard.  # noqa: E501
        :type: ConnectionDetails
        """

        self._details = details

    @property
    def steps(self):
        """Gets the steps of this SourceReportCard.  # noqa: E501

        A sequential list of Connection Step objects required to complete configuration for the connection type.   # noqa: E501

        :return: The steps of this SourceReportCard.  # noqa: E501
        :rtype: list[ConnectionStep]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """Sets the steps of this SourceReportCard.

        A sequential list of Connection Step objects required to complete configuration for the connection type.   # noqa: E501

        :param steps: The steps of this SourceReportCard.  # noqa: E501
        :type: list[ConnectionStep]
        """

        self._steps = steps

    @property
    def type(self):
        """Gets the type of this SourceReportCard.  # noqa: E501

        The connection type. Ex: platform.mysql or platform.hubspot   # noqa: E501

        :return: The type of this SourceReportCard.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SourceReportCard.

        The connection type. Ex: platform.mysql or platform.hubspot   # noqa: E501

        :param type: The type of this SourceReportCard.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceReportCard):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SourceReportCard):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from stitch_connect_client.models.azure_destination_form_properties import (
    AzureDestinationFormProperties,
)
from stitch_connect_client.models.connection_check import ConnectionCheck
from stitch_connect_client.models.connection_details import ConnectionDetails
from stitch_connect_client.models.connection_step import ConnectionStep
from stitch_connect_client.models.connection_step_props import ConnectionStepProps
from stitch_connect_client.models.connection_step_props_any_of import (
    ConnectionStepPropsAnyOf,
)
from stitch_connect_client.models.connection_step_props_json_schema import (
    ConnectionStepPropsJsonSchema,
)
from stitch_connect_client.models.create_destination_body import CreateDestinationBody
from stitch_connect_client.models.create_source_body import CreateSourceBody
from stitch_connect_client.models.destination import Destination
from stitch_connect_client.models.destination_form_properties import (
    DestinationFormProperties,
)
from stitch_connect_client.models.destination_report_card import DestinationReportCard
from stitch_connect_client.models.error_object import ErrorObject
from stitch_connect_client.models.error_object_error import ErrorObjectError
from stitch_connect_client.models.field_level_metadata import FieldLevelMetadata
from stitch_connect_client.models.forced_replication_method import (
    ForcedReplicationMethod,
)
from stitch_connect_client.models.forced_replication_method_object import (
    ForcedReplicationMethodObject,
)
from stitch_connect_client.models.google_analytics_source_form_properties import (
    GoogleAnalyticsSourceFormProperties,
)
from stitch_connect_client.models.google_analytics_source_form_properties_report_definitions import (
    GoogleAnalyticsSourceFormPropertiesReportDefinitions,
)
from stitch_connect_client.models.hook_notification import HookNotification
from stitch_connect_client.models.hook_notification_config import HookNotificationConfig
from stitch_connect_client.models.metadata import Metadata
from stitch_connect_client.models.metadata_object import MetadataObject
from stitch_connect_client.models.mixpanel_source_form_properties import (
    MixpanelSourceFormProperties,
)
from stitch_connect_client.models.replication_job import ReplicationJob
from stitch_connect_client.models.s3_destination_form_properties import (
    S3DestinationFormProperties,
)
from stitch_connect_client.models.salesforce_source_form_properties import (
    SalesforceSourceFormProperties,
)
from stitch_connect_client.models.source import Source
from stitch_connect_client.models.source_form_properties import SourceFormProperties
from stitch_connect_client.models.source_report_card import SourceReportCard
from stitch_connect_client.models.stream import Stream
from stitch_connect_client.models.stream_level_metadata import StreamLevelMetadata
from stitch_connect_client.models.stream_schema import StreamSchema
from stitch_connect_client.models.stream_update import StreamUpdate
from stitch_connect_client.models.streams_update_list import StreamsUpdateList
from stitch_connect_client.models.update_source_body import UpdateSourceBody



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class ConnectionStepProps(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "is_required": "bool",
        "is_credential": "bool",
        "property_type": "str",
        "json_schema": "list[ConnectionStepPropsJsonSchema]",
        "provided": "bool",
    }

    attribute_map = {
        "name": "name",
        "is_required": "is_required",
        "is_credential": "is_credential",
        "property_type": "property_type",
        "json_schema": "json_schema",
        "provided": "provided",
    }

    def __init__(
        self,
        name=None,
        is_required=None,
        is_credential=None,
        property_type=None,
        json_schema=None,
        provided=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ConnectionStepProps - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._is_required = None
        self._is_credential = None
        self._property_type = None
        self._json_schema = None
        self._provided = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if is_required is not None:
            self.is_required = is_required
        if is_credential is not None:
            self.is_credential = is_credential
        if property_type is not None:
            self.property_type = property_type
        if json_schema is not None:
            self.json_schema = json_schema
        if provided is not None:
            self.provided = provided

    @property
    def name(self):
        """Gets the name of this ConnectionStepProps.  # noqa: E501

        The name of the property.  # noqa: E501

        :return: The name of this ConnectionStepProps.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConnectionStepProps.

        The name of the property.  # noqa: E501

        :param name: The name of this ConnectionStepProps.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def is_required(self):
        """Gets the is_required of this ConnectionStepProps.  # noqa: E501

        If true, the property is required for complete configuration.  # noqa: E501

        :return: The is_required of this ConnectionStepProps.  # noqa: E501
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """Sets the is_required of this ConnectionStepProps.

        If true, the property is required for complete configuration.  # noqa: E501

        :param is_required: The is_required of this ConnectionStepProps.  # noqa: E501
        :type: bool
        """

        self._is_required = is_required

    @property
    def is_credential(self):
        """Gets the is_credential of this ConnectionStepProps.  # noqa: E501

        If true, the property is a credential or otherwise sensitive data.   # noqa: E501

        :return: The is_credential of this ConnectionStepProps.  # noqa: E501
        :rtype: bool
        """
        return self._is_credential

    @is_credential.setter
    def is_credential(self, is_credential):
        """Sets the is_credential of this ConnectionStepProps.

        If true, the property is a credential or otherwise sensitive data.   # noqa: E501

        :param is_credential: The is_credential of this ConnectionStepProps.  # noqa: E501
        :type: bool
        """

        self._is_credential = is_credential

    @property
    def property_type(self):
        """Gets the property_type of this ConnectionStepProps.  # noqa: E501

        Indicates the type of the property. Possible values are: user_provided - Indicates the property must be set by the user. read_only - Indicates the property is read-only and is not settable by the Generally, this is an internal field set inside of Stitch. system_provided_by_default - Indicates the property used to be system_provided: true, but can now be set by the API consumer. These are generally properties associated with OAuth for generating refresh and access tokens. user_provided_advanced - Indicates the property is set by the user but may be configured by the Stitch support team in the event that the integration is failing to work properly. Note: Use caution when setting these properties, as using incorrect values can put the source into a non-functioning state.   # noqa: E501

        :return: The property_type of this ConnectionStepProps.  # noqa: E501
        :rtype: str
        """
        return self._property_type

    @property_type.setter
    def property_type(self, property_type):
        """Sets the property_type of this ConnectionStepProps.

        Indicates the type of the property. Possible values are: user_provided - Indicates the property must be set by the user. read_only - Indicates the property is read-only and is not settable by the Generally, this is an internal field set inside of Stitch. system_provided_by_default - Indicates the property used to be system_provided: true, but can now be set by the API consumer. These are generally properties associated with OAuth for generating refresh and access tokens. user_provided_advanced - Indicates the property is set by the user but may be configured by the Stitch support team in the event that the integration is failing to work properly. Note: Use caution when setting these properties, as using incorrect values can put the source into a non-functioning state.   # noqa: E501

        :param property_type: The property_type of this ConnectionStepProps.  # noqa: E501
        :type: str
        """

        self._property_type = property_type

    @property
    def json_schema(self):
        """Gets the json_schema of this ConnectionStepProps.  # noqa: E501

        Note: Data will only be returned for this array if property_type: user_provided or property_type: system_provided_by_default. If property_type: read_only, this property will be null. An array containing: type - A string indicating the expected data type of the property's value. For example: boolean pattern - A string indicating the expected pattern of the property's value. For example: ^\\\\d+$ anyOf - A series of arrays containing key-value pairs for the type and format combinations Stitch will accept as the property's value   # noqa: E501

        :return: The json_schema of this ConnectionStepProps.  # noqa: E501
        :rtype: list[ConnectionStepPropsJsonSchema]
        """
        return self._json_schema

    @json_schema.setter
    def json_schema(self, json_schema):
        """Sets the json_schema of this ConnectionStepProps.

        Note: Data will only be returned for this array if property_type: user_provided or property_type: system_provided_by_default. If property_type: read_only, this property will be null. An array containing: type - A string indicating the expected data type of the property's value. For example: boolean pattern - A string indicating the expected pattern of the property's value. For example: ^\\\\d+$ anyOf - A series of arrays containing key-value pairs for the type and format combinations Stitch will accept as the property's value   # noqa: E501

        :param json_schema: The json_schema of this ConnectionStepProps.  # noqa: E501
        :type: list[ConnectionStepPropsJsonSchema]
        """

        self._json_schema = json_schema

    @property
    def provided(self):
        """Gets the provided of this ConnectionStepProps.  # noqa: E501

        If true, the property has been provided. For properties where property_type: user_provided, this indicates that the user has provided the property.   # noqa: E501

        :return: The provided of this ConnectionStepProps.  # noqa: E501
        :rtype: bool
        """
        return self._provided

    @provided.setter
    def provided(self, provided):
        """Sets the provided of this ConnectionStepProps.

        If true, the property has been provided. For properties where property_type: user_provided, this indicates that the user has provided the property.   # noqa: E501

        :param provided: The provided of this ConnectionStepProps.  # noqa: E501
        :type: bool
        """

        self._provided = provided

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectionStepProps):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectionStepProps):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class HookNotificationConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"url": "str"}

    attribute_map = {"url": "url"}

    def __init__(self, url=None, local_vars_configuration=None):  # noqa: E501
        """HookNotificationConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._url = None
        self.discriminator = None

        if url is not None:
            self.url = url

    @property
    def url(self):
        """Gets the url of this HookNotificationConfig.  # noqa: E501

        Applicable to hook notifications only. The webhook URL that Stitch should deliver hook notifications to.   # noqa: E501

        :return: The url of this HookNotificationConfig.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this HookNotificationConfig.

        Applicable to hook notifications only. The webhook URL that Stitch should deliver hook notifications to.   # noqa: E501

        :param url: The url of this HookNotificationConfig.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HookNotificationConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HookNotificationConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Stitch Connect

    https://www.stitchdata.com/docs/developers/stitch-connect/api  # noqa: E501

    The version of the OpenAPI document: 0.4.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from stitch_connect_client.configuration import Configuration


class ConnectionDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "access": "bool",
        "default_scheduling_interval": "int",
        "pricing_tier": "str",
        "default_start_date": "str",
        "pipeline_state": "str",
        "protocol": "str",
    }

    attribute_map = {
        "access": "access",
        "default_scheduling_interval": "default_scheduling_interval",
        "pricing_tier": "pricing_tier",
        "default_start_date": "default_start_date",
        "pipeline_state": "pipeline_state",
        "protocol": "protocol",
    }

    def __init__(
        self,
        access=None,
        default_scheduling_interval=None,
        pricing_tier=None,
        default_start_date=None,
        pipeline_state=None,
        protocol=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ConnectionDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access = None
        self._default_scheduling_interval = None
        self._pricing_tier = None
        self._default_start_date = None
        self._pipeline_state = None
        self._protocol = None
        self.discriminator = None

        if access is not None:
            self.access = access
        if default_scheduling_interval is not None:
            self.default_scheduling_interval = default_scheduling_interval
        if pricing_tier is not None:
            self.pricing_tier = pricing_tier
        if default_start_date is not None:
            self.default_start_date = default_start_date
        if pipeline_state is not None:
            self.pipeline_state = pipeline_state
        if protocol is not None:
            self.protocol = protocol

    @property
    def access(self):
        """Gets the access of this ConnectionDetails.  # noqa: E501

        Indicates whether the Stitch client who made the request has access to the connection. This value is based on the connection's pricing_tier and pipeline_state. If the Stitch client is using a plan that doesn't meet the pricing_tier requirement, the access value will be false. For example: If pricing_tier: enterprise,the Stitch client must be on an Enterprise plan to access the source. All connections with a pipeline_state value of deprecated will also have an access value of false.   # noqa: E501

        :return: The access of this ConnectionDetails.  # noqa: E501
        :rtype: bool
        """
        return self._access

    @access.setter
    def access(self, access):
        """Sets the access of this ConnectionDetails.

        Indicates whether the Stitch client who made the request has access to the connection. This value is based on the connection's pricing_tier and pipeline_state. If the Stitch client is using a plan that doesn't meet the pricing_tier requirement, the access value will be false. For example: If pricing_tier: enterprise,the Stitch client must be on an Enterprise plan to access the source. All connections with a pipeline_state value of deprecated will also have an access value of false.   # noqa: E501

        :param access: The access of this ConnectionDetails.  # noqa: E501
        :type: bool
        """

        self._access = access

    @property
    def default_scheduling_interval(self):
        """Gets the default_scheduling_interval of this ConnectionDetails.  # noqa: E501

        Applicable only to source report cards. The default frequency_in_minutes value for the source.   # noqa: E501

        :return: The default_scheduling_interval of this ConnectionDetails.  # noqa: E501
        :rtype: int
        """
        return self._default_scheduling_interval

    @default_scheduling_interval.setter
    def default_scheduling_interval(self, default_scheduling_interval):
        """Sets the default_scheduling_interval of this ConnectionDetails.

        Applicable only to source report cards. The default frequency_in_minutes value for the source.   # noqa: E501

        :param default_scheduling_interval: The default_scheduling_interval of this ConnectionDetails.  # noqa: E501
        :type: int
        """

        self._default_scheduling_interval = default_scheduling_interval

    @property
    def pricing_tier(self):
        """Gets the pricing_tier of this ConnectionDetails.  # noqa: E501

        Indicates the type of Stitch plan required to use the connection. Possible values are: standard - Any Stitch plan can use the connection. premium - A Standard Stitch plan is required to use the connection. enterprise - An Enterprise Stitch plan is required to use the connection.   # noqa: E501

        :return: The pricing_tier of this ConnectionDetails.  # noqa: E501
        :rtype: str
        """
        return self._pricing_tier

    @pricing_tier.setter
    def pricing_tier(self, pricing_tier):
        """Sets the pricing_tier of this ConnectionDetails.

        Indicates the type of Stitch plan required to use the connection. Possible values are: standard - Any Stitch plan can use the connection. premium - A Standard Stitch plan is required to use the connection. enterprise - An Enterprise Stitch plan is required to use the connection.   # noqa: E501

        :param pricing_tier: The pricing_tier of this ConnectionDetails.  # noqa: E501
        :type: str
        """
        allowed_values = ["standard", "premium", "enterprise"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and pricing_tier not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `pricing_tier` ({0}), must be one of {1}".format(  # noqa: E501
                    pricing_tier, allowed_values
                )
            )

        self._pricing_tier = pricing_tier

    @property
    def default_start_date(self):
        """Gets the default_start_date of this ConnectionDetails.  # noqa: E501

        Applicable only to source report cards. The default start_date value for the source.   # noqa: E501

        :return: The default_start_date of this ConnectionDetails.  # noqa: E501
        :rtype: str
        """
        return self._default_start_date

    @default_start_date.setter
    def default_start_date(self, default_start_date):
        """Sets the default_start_date of this ConnectionDetails.

        Applicable only to source report cards. The default start_date value for the source.   # noqa: E501

        :param default_start_date: The default_start_date of this ConnectionDetails.  # noqa: E501
        :type: str
        """

        self._default_start_date = default_start_date

    @property
    def pipeline_state(self):
        """Gets the pipeline_state of this ConnectionDetails.  # noqa: E501

        The connection type's release status in Stitch. Possible values are: alpha - The connection is in development and is not available in Stitch. beta - The connection is in open or closed beta and is available in Stitch. released - The connection is in general release and available in Stitch. deprecated - The connection has been deprecated and is no longer available in Stitch.   # noqa: E501

        :return: The pipeline_state of this ConnectionDetails.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_state

    @pipeline_state.setter
    def pipeline_state(self, pipeline_state):
        """Sets the pipeline_state of this ConnectionDetails.

        The connection type's release status in Stitch. Possible values are: alpha - The connection is in development and is not available in Stitch. beta - The connection is in open or closed beta and is available in Stitch. released - The connection is in general release and available in Stitch. deprecated - The connection has been deprecated and is no longer available in Stitch.   # noqa: E501

        :param pipeline_state: The pipeline_state of this ConnectionDetails.  # noqa: E501
        :type: str
        """
        allowed_values = ["alpha", "beta", "released", "deprecated"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and pipeline_state not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `pipeline_state` ({0}), must be one of {1}".format(  # noqa: E501
                    pipeline_state, allowed_values
                )
            )

        self._pipeline_state = pipeline_state

    @property
    def protocol(self):
        """Gets the protocol of this ConnectionDetails.  # noqa: E501

        The type of the connection. For example: snowflake or platform.facebook   # noqa: E501

        :return: The protocol of this ConnectionDetails.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this ConnectionDetails.

        The type of the connection. For example: snowflake or platform.facebook   # noqa: E501

        :param protocol: The protocol of this ConnectionDetails.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectionDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectionDetails):
            return True

        return self.to_dict() != other.to_dict()
